import { Connect, CredentialManager, MessageBuilder } from '@genesislcap/foundation-comms';
import type { Message } from '@genesislcap/foundation-comms';
import { AbstractMachine, FetchMachine, FetchMachineEvent, Machine } from '@genesislcap/foundation-state-machine';
import { UUID } from '@genesislcap/foundation-utils';
import type { InterpreterOptions } from 'xstate';
import { User } from '../entity';
import { AuthConfig } from '../main/config';
import { LoginMapper, LogoutMapper } from '../mapper';
import type { AuthMachineContext, AuthMachineEvent } from './types';
/**
 * AuthMachine interface.
 * @public
 */
export interface AuthMachine extends Machine<AuthMachineContext, AuthMachineEvent> {
}
/**
 * Default AuthMachine.
 * @public
 */
export declare class DefaultAuthMachine extends AbstractMachine<AuthMachineContext, AuthMachineEvent> implements AuthMachine {
    private user;
    private connect;
    private fetchMachine;
    private messageBuilder;
    private credentialManager;
    private uuid;
    private loginMapper;
    private logoutMapper;
    private config;
    constructor(user: User, connect: Connect, fetchMachine: FetchMachine, messageBuilder: MessageBuilder, credentialManager: CredentialManager, uuid: UUID, loginMapper: LoginMapper, logoutMapper: LogoutMapper, config: AuthConfig);
    start(options?: InterpreterOptions<typeof this.machine>): void;
    /**
     * AuthMachine is a singleton.
     */
    getFromContainer(): this;
    createFetchMachineEvent(url: string, msg?: Message): FetchMachineEvent;
    addLoginEvents(): {
        login: {
            actions: string[];
            target: string;
        };
        "login-details": {
            target: string;
        };
    };
}
/**
 * AuthMachine DI key.
 * @internal
 */
export declare const AuthMachine: import("@microsoft/fast-foundation").InterfaceSymbol<AuthMachine>;
//# sourceMappingURL=machine.d.ts.map