import type { AuthInfo } from '@genesislcap/foundation-comms';
import type { MachineContext } from '@genesislcap/foundation-state-machine';
import type { DoneInvokeEvent, ErrorEvent } from 'xstate';
import type { User } from '../entity';
import type { AuthDTO, AuthEntity, Mapper } from '../mapper';
/**
 * AuthMachineContext interface.
 * @remarks
 * Transient state during the machine's execution.
 * @public
 */
export interface AuthMachineContext extends MachineContext {
    /**
     * The authentication credentials.
     * @remarks
     * Optional as it's possible to reauthenticate silently.
     */
    credentials?: AuthInfo;
    /**
     * The login/login DTO from the fetch machine.
     */
    authDTO: AuthDTO;
    /**
     * The login/login Entity mapped from the DTO.
     */
    authEntity: AuthEntity;
    /**
     * The mapper for the action being taken.
     */
    mapper: Mapper<AuthDTO, AuthEntity>;
    /**
     * The user, either authenticated or anonymous.
     */
    user: User;
}
/**
 * AuthMachineEvent type.
 * @remarks
 * The send action events used to invoke the machine.
 * @public
 */
export type AuthMachineEvent = {
    type: 'login';
    params: {
        credentials?: AuthInfo;
    };
} | {
    type: 'logout';
} | {
    type: 'openSocket';
} | {
    type: 'closeSocket';
} | {
    type: 'login-details';
} | DoneInvokeEvent<unknown> | ErrorEvent<unknown>;
/**
 * AuthMachineEventMap type.
 * @remarks
 * The mediation CustomEvent used to invoke machine actions.
 * @public
 */
export type AuthMachineEventMap = {
    'auth-machine-event': AuthMachineEvent;
};
/**
 * Default AuthMachineContext.
 * @public
 */
export declare const defaultAuthMachineContext: Partial<AuthMachineContext>;
//# sourceMappingURL=types.d.ts.map