import type { LoginDTO, LoginEntity } from './loginMapper';
import type { LogoutDTO, LogoutEntity } from './logoutMapper';
/**
 * DTO mapper interface.
 * @typeParam TDTO - The dto type.
 * @typeParam TEntity - The entity type.
 * @public
 */
export interface Mapper<TDTO, TEntity> {
    /**
     * Converts a DTO to an entity.
     * @param dto - The DTO to convert.
     * @returns Promise of the resulting entity.
     */
    toEntity: (dto: TDTO) => Promise<TEntity>;
    /**
     * Converts an entity to a DTO.
     * @remarks
     * This is optionally implemented as many DTOs are never sent back to the server.
     * @param entity - The entity to convert.
     * @returns Promise of the resulting DTO.
     */
    toDTO?: (entity: Partial<TEntity>) => Promise<TDTO>;
}
/**
 * @public
 */
export type AuthDTO = LoginDTO | LogoutDTO;
/**
 * @public
 */
export type AuthEntity = LoginEntity | LogoutEntity;
//# sourceMappingURL=types.d.ts.map