import { __awaiter } from "tslib";
import { DI } from '@microsoft/fast-foundation';
import { logger } from '../utils';
import { fromDTOAck, fromDTONack } from './utils';
/**
 * isLogoutAckDTO.
 * @param dto - Potential DTO.
 * @public
 */
export function isLogoutAckDTO(dto) {
    return (dto === null || dto === void 0 ? void 0 : dto.MESSAGE_TYPE) === 'LOGOUT_ACK';
}
/**
 * isLogoutNackDTO.
 * @param dto - Potential DTO.
 * @public
 */
export function isLogoutNackDTO(dto) {
    return (dto === null || dto === void 0 ? void 0 : dto.MESSAGE_TYPE) === 'EVENT_LOGOUT_NACK';
}
/**
 * isLogoutAckEntity.
 * @param entity - Potential entity.
 * @public
 */
export function isLogoutAckEntity(entity) {
    return (entity === null || entity === void 0 ? void 0 : entity.messageType) === 'LOGOUT_ACK';
}
/**
 * isLogoutNackEntity.
 * @param entity - Potential entity.
 * @public
 */
export function isLogoutNackEntity(entity) {
    return (entity === null || entity === void 0 ? void 0 : entity.messageType) === 'EVENT_LOGOUT_NACK';
}
/**
 * Default LogoutMapper.
 * @public
 */
export class DefaultLogoutMapper {
    constructor() {
        /**
         * {@inheritDoc Mapper.toEntity}
         */
        this.toEntity = (dto) => __awaiter(this, void 0, void 0, function* () {
            try {
                if (isLogoutNackDTO(dto)) {
                    return fromDTONack(dto);
                }
                if (isLogoutAckDTO(dto)) {
                    return Object.assign(Object.assign({}, fromDTOAck(dto)), { oidcLogoutUrl: dto.OIDC_LOGOUT_URL });
                }
            }
            catch (e) {
                logger.error(e);
                throw e;
            }
        });
    }
}
/**
 * LogoutMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export const LogoutMapper = DI.createInterface((x) => x.singleton(DefaultLogoutMapper));
