import { sync } from '@genesislcap/foundation-utils';
import { html, repeat, when } from '@microsoft/fast-element';
import { organisationField, passwordField, showPasswordsCheckbox, usernameField, submitButton, } from '../base';
const regularLogin = html `
  ${when((login) => !login.store.formEntry.ssoToggled, html `
      ${organisationField()} ${usernameField()} ${passwordField()}
      <span class="case-warning">*Fields are case-sensitive</span>
      ${showPasswordsCheckbox()}
      <div class="form-buttons">
        ${(x) => submitButton('Login', 'submit-login', x.submitDisabled)}
        <div class="links">
          <div class="password-links">
            ${when((x) => !x.config.omitRoutes.includes('forgot-password'), html `
                <a
                  class="link-url"
                  @click=${(x) => x.onNavigate(x.getSubRoutePath(`forgot-password`))}
                  data-test-id="forgot-password"
                >
                  Forgot Password?
                </a>
              `)}
            ${when((x) => !x.config.omitRoutes.includes('reset-password'), html `
                <a
                  class="link-url"
                  @click=${(x) => x.onNavigate(x.getSubRoutePath(`reset-password`))}
                  data-test-id="reset-password"
                >
                  Change Password
                </a>
              `)}
          </div>
          <div class="account-links">
            ${when((x) => !x.config.omitRoutes.includes('request-account'), html `
                <a
                  class="link-url"
                  @click=${(x) => x.onNavigate(x.getSubRoutePath(`request-account`))}
                  data-test-id="request-account"
                >
                  Request Account
                </a>
              `)}
            <a class="link-url" @click=${(x) => x.logout()}>Logout Test</a>
            <a class="link-url" @click=${(x) => x.onOpenSocketTest()}>Socket Open Test</a>
            <a class="link-url" @click=${(x) => x.onCloseSocketTest()}>Socket Close Test</a>
            <a class="link-url" @click=${(x) => x.onLoginDetailsTest()}>Login Details Test</a>
            <pre>snapshot: ${(x) => JSON.stringify(x.store.authMachine.snapshot)}</pre>
            <pre>state: ${(x) => JSON.stringify(x.store.authMachine.state)}</pre>
            <pre>context: ${(x) => JSON.stringify(x.store.authMachine.errors.messages)}</pre>
            <pre>meta: ${(x) => JSON.stringify(x.store.authMachine.getMetaValuesByKey())}</pre>
            ${when((x) => !!x.store.authMachine.errors.size, html `
                <span>${(x) => x.store.authMachine.errors.messages}</span>
              `)}
            ${when((x) => x.store.authMachine.hasTag('pending'), html `
                <h4>PENDING...</h4>
              `)}
            ${when((x) => x.store.authMachine.matches('loggedOut'), html `
                <h4>loggedOut...</h4>
              `)}
            ${when((x) => x.store.authMachine.matches('idle'), html `
                <h4>idle...</h4>
              `)}
            ${when((x) => x.store.authMachine.matches('authCheck'), html `
                <h4>authCheck...</h4>
              `)}
          </div>
        </div>
      </div>
      ${when((x) => x.config.versionInformation, html `
          <div>
            <span class="version" data-test-id="version">
              ${(x) => x.config.versionInformation}
            </span>
          </div>
        `)}
    `)}
`;
const ssoLogin = html `
  ${when((login) => login.store.formEntry.ssoToggled, html `
      <div class="sso">
        <span class="form-title">Providers</span>
        <zero-select
          name="sso"
          data-test-id="sso"
          :value=${sync((x) => x.selectedIDP)}
          ?disabled=${(x) => !x.idps.length}
        >
          ${repeat((x) => x.idps, html `
              <zero-option value="${({ id }) => id}">${({ id }) => id}</zero-option>
            `)}
        </zero-select>
        <zero-button
          type="button"
          class="action-btn"
          appearance="primary-gradient"
          @click="${(x) => x.onClickSSO()}"
          data-test-id="sso-login"
          ?disabled=${(x) => !x.selectedIDP}
        >
          SSO Login
        </zero-button>
      </div>
    `)}
`;
const httpModeEnabledText = html `
  <pre data-test-id="connect-http-mode">Http Polling Mode Enabled.</pre>
`;
const httpMode = html `
  ${(x) => (x.connect.httpMode() ? httpModeEnabledText : null)}
`;
const connectionIndicator = html `
  <zero-connection-indicator show-label="true" />
`;
const connectionIndicatorWrapper = html `
  ${(x) => (x.connect.httpMode() ? null : connectionIndicator)}
`;
export const LoginTemplate = html `
  <auth-background>
    <div class="container">
      <zero-card class="card-pd">
        <div class="column-content">
          <auth-logo></auth-logo>
          <div class="heading2">Login</div>
        </div>
        <form
          id="auth-login"
          method="post"
          autocomplete="on"
          @submit=${(x) => x.onLoginSubmit()}
          ?disabled=${(x) => x.submitDisabled}
          data-test-id="auth-login"
        >
          ${regularLogin} ${ssoLogin}
          ${when((x) => x.config.sso, html `
              <zero-checkbox
                ?checked="${sync((x) => x.store.formEntry.ssoToggled, 'boolean')}"
                name="sso-toggle"
                data-test-id="sso-toggle"
              >
                ${(x) => x.store.formEntry.ssoToggled ? 'SSO Enabled' + x.selectedIDPName : 'Enable SSO?'}
              </zero-checkbox>
            `)}
          <auth-message
            message="${(x) => x.message}"
            non-error="${(x) => !x.hasErrors}"
          ></auth-message>
          ${when((x) => x.config.showConnectionIndicator, html `
              ${connectionIndicatorWrapper}
            `)}
        </form>
      </zero-card>
    </div>
  </auth-background>
`;
