import { AbstractMachine } from '@genesislcap/foundation-state-machine';
import { AbstractStore } from '@genesislcap/foundation-store';
import { AbstractStoreRoot } from '@genesislcap/foundation-store';
import { Auth as Auth_2 } from '@genesislcap/foundation-comms';
import { AuthInfo } from '@genesislcap/foundation-comms';
import { Binding } from '@microsoft/fast-element';
import { Connect } from '@genesislcap/foundation-comms';
import { Constructable } from '@microsoft/fast-element';
import { Container } from '@microsoft/fast-foundation';
import { Controller } from '@microsoft/fast-element';
import { CredentialManager } from '@genesislcap/foundation-comms';
import { DefineFunction } from '@genesislcap/foundation-ui';
import type { DoneInvokeEvent } from 'xstate';
import { ElementStyles } from '@microsoft/fast-element';
import { EmitOptions } from '@genesislcap/foundation-events';
import { EmitReturn } from '@genesislcap/foundation-events';
import type { ErrorEvent as ErrorEvent_2 } from 'xstate';
import { FASTElement } from '@microsoft/fast-element';
import { FetchMachine } from '@genesislcap/foundation-state-machine';
import { FetchMachineEvent } from '@genesislcap/foundation-state-machine';
import { FoundationAnalytics } from '@genesislcap/foundation-comms';
import { GenesisServerError } from '@genesislcap/foundation-state-machine';
import { InterfaceSymbol } from '@microsoft/fast-foundation';
import type { InterpreterOptions } from 'xstate';
import { Key } from '@microsoft/fast-foundation';
import { KeysMatching } from '@genesislcap/foundation-events';
import { Logger } from '@genesislcap/foundation-utils';
import { Machine } from '@genesislcap/foundation-state-machine';
import type { MachineContext } from '@genesislcap/foundation-state-machine';
import { Message as Message_2 } from '@genesislcap/foundation-comms';
import { MessageBuilder } from '@genesislcap/foundation-comms';
import { NavigationPhase } from '@microsoft/fast-router';
import { PartialFASTElementDefinition } from '@microsoft/fast-element';
import { RouterConfiguration } from '@microsoft/fast-router';
import { Session } from '@genesislcap/foundation-comms';
import { Store } from '@genesislcap/foundation-store';
import { StoreRoot } from '@genesislcap/foundation-store';
import { StoreRootEventDetailMap } from '@genesislcap/foundation-store';
import { SyntheticViewTemplate } from '@microsoft/fast-element';
import { TemplateElementDependency } from '@genesislcap/foundation-ui';
import { UUID } from '@genesislcap/foundation-utils';
import { ViewTemplate } from '@microsoft/fast-element';

/**
 * @internal
 */
declare interface ACK extends MESSAGE {
}

/**
 * @internal
 */
declare interface Ack extends Message {
}

/**
 * @public
 */
export declare class Auth extends Auth_base {
    /**
     * @internal
     */
    store: AuthStore;
    /**
     * @internal
     */
    cm: CredentialManager;
    /**
     * Configuration for the routes and their associated settings.
     * The client would override this in their app with their own settings to set
     * their routes up as desired
     * @internal
     */
    config: MainRouterConfig;
    /**
     * The DI container used to register required components in {@link Auth.registerDIDependencies}
     * @internal
     */
    container: Container;
    /**
     * Session controller used to manage the user's session
     * @internal
     */
    session: Session;
    /**
     * Marked true when remote components are loaded, currently unused.
     * @internal
     */
    ready: boolean;
    /**
     * DS provider / root level template.
     * @internal
     */
    provider: HTMLElement;
    /**
     * @internal
     */
    connectedCallback(): Promise<void>;
    /**
     * @internal
     */
    disconnectedCallback(): void;
    /**
     * Used to forward the user onto a logged-in session during an SSO and MFA journeys
     *
     * @remarks
     *
     * Called when loading the login page via the connectedCallback() method.
     * During normal flows there will be no SSO tokens set and hence this function
     * will quit execution.
     * During an SSO journey the SSO provider will set the SSO token as a URLSearchParams
     * parameter and redirect back to us. In this case we will take this and forward the
     * user on, with their logged in session.
     *
     * There are two paths the user can take here - if they are in a popup
     * (window.opener exists) then we need to set the session and get the parent window
     * (the one which the user wants their session on) to refresh, and close the popup.
     *
     * Or if they are not in a popup then we simply set the ssoToken in the session.
     * When this component is loaded with the ssoToken then it will redirect the
     * user to their app (the `defaultRedirectUrl`).
     *
     * @internal
     */
    actionQueryParams(): void;
    /**
     * Called from the connectedCallback
     * @internal
     */
    registerCommonComponents(): Promise<void>;
    /**
     * @internal
     */
    protected registerDIDependencies(): void;
    /**
     * @internal
     */
    protected addEventListeners(): void;
    /**
     * @internal
     */
    protected removeEventListeners(): void;
    /**
     * @internal
     */
    protected readyStore(): void;
    loginWithCredentials(credentials: AuthInfo): void;
    loginWithCookies(): void;
    logout(): void;
}

declare const Auth_base: abstract new (...args: any[]) => {
    $emit<K extends "store-connected" | "store-disconnected" | "store-ready" | "auth-machine-event" | "auth-login" | "auth-login-details" | "auth-logout">(...args: AuthEventMap[K] extends void ? [type: K, options?: EmitOptions] : [type: K, detail: AuthEventMap[K], options?: EmitOptions]): EmitReturn;
    accessKey: string;
    readonly accessKeyLabel: string;
    autocapitalize: string;
    dir: string;
    draggable: boolean;
    hidden: boolean;
    inert: boolean;
    innerText: string;
    lang: string;
    readonly offsetHeight: number;
    readonly offsetLeft: number;
    readonly offsetParent: Element;
    readonly offsetTop: number;
    readonly offsetWidth: number;
    outerText: string;
    spellcheck: boolean;
    title: string;
    translate: boolean;
    attachInternals(): ElementInternals;
    click(): void;
    addEventListener<K_1 extends keyof HTMLElementEventMap>(type: K_1, listener: (this: HTMLElement, ev: HTMLElementEventMap[K_1]) => any, options?: boolean | AddEventListenerOptions): void;
    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;
    removeEventListener<K_2 extends keyof HTMLElementEventMap>(type: K_2, listener: (this: HTMLElement, ev: HTMLElementEventMap[K_2]) => any, options?: boolean | EventListenerOptions): void;
    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;
    readonly attributes: NamedNodeMap;
    readonly classList: DOMTokenList;
    className: string;
    readonly clientHeight: number;
    readonly clientLeft: number;
    readonly clientTop: number;
    readonly clientWidth: number;
    id: string;
    readonly localName: string;
    readonly namespaceURI: string;
    onfullscreenchange: (this: Element, ev: Event) => any;
    onfullscreenerror: (this: Element, ev: Event) => any;
    outerHTML: string;
    readonly ownerDocument: Document;
    readonly part: DOMTokenList;
    readonly prefix: string;
    readonly scrollHeight: number;
    scrollLeft: number;
    scrollTop: number;
    readonly scrollWidth: number;
    readonly shadowRoot: ShadowRoot;
    slot: string;
    readonly tagName: string;
    attachShadow(init: ShadowRootInit): ShadowRoot;
    closest<K_3 extends keyof HTMLElementTagNameMap>(selector: K_3): HTMLElementTagNameMap[K_3];
    closest<K_4 extends keyof SVGElementTagNameMap>(selector: K_4): SVGElementTagNameMap[K_4];
    closest<E extends Element = Element>(selectors: string): E;
    getAttribute(qualifiedName: string): string;
    getAttributeNS(namespace: string, localName: string): string;
    getAttributeNames(): string[];
    getAttributeNode(qualifiedName: string): Attr;
    getAttributeNodeNS(namespace: string, localName: string): Attr;
    getBoundingClientRect(): DOMRect;
    getClientRects(): DOMRectList;
    getElementsByClassName(classNames: string): HTMLCollectionOf<Element>;
    getElementsByTagName<K_5 extends keyof HTMLElementTagNameMap>(qualifiedName: K_5): HTMLCollectionOf<HTMLElementTagNameMap[K_5]>;
    getElementsByTagName<K_6 extends keyof SVGElementTagNameMap>(qualifiedName: K_6): HTMLCollectionOf<SVGElementTagNameMap[K_6]>;
    getElementsByTagName(qualifiedName: string): HTMLCollectionOf<Element>;
    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/1999/xhtml", localName: string): HTMLCollectionOf<HTMLElement>;
    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/2000/svg", localName: string): HTMLCollectionOf<SVGElement>;
    getElementsByTagNameNS(namespace: string, localName: string): HTMLCollectionOf<Element>;
    hasAttribute(qualifiedName: string): boolean;
    hasAttributeNS(namespace: string, localName: string): boolean;
    hasAttributes(): boolean;
    hasPointerCapture(pointerId: number): boolean;
    insertAdjacentElement(where: InsertPosition, element: Element): Element;
    insertAdjacentHTML(position: InsertPosition, text: string): void;
    insertAdjacentText(where: InsertPosition, data: string): void;
    matches(selectors: string): boolean;
    releasePointerCapture(pointerId: number): void;
    removeAttribute(qualifiedName: string): void;
    removeAttributeNS(namespace: string, localName: string): void;
    removeAttributeNode(attr: Attr): Attr;
    requestFullscreen(options?: FullscreenOptions): Promise<void>;
    requestPointerLock(): void;
    scroll(options?: ScrollToOptions): void;
    scroll(x: number, y: number): void;
    scrollBy(options?: ScrollToOptions): void;
    scrollBy(x: number, y: number): void;
    scrollIntoView(arg?: boolean | ScrollIntoViewOptions): void;
    scrollTo(options?: ScrollToOptions): void;
    scrollTo(x: number, y: number): void;
    setAttribute(qualifiedName: string, value: string): void;
    setAttributeNS(namespace: string, qualifiedName: string, value: string): void;
    setAttributeNode(attr: Attr): Attr;
    setAttributeNodeNS(attr: Attr): Attr;
    setPointerCapture(pointerId: number): void;
    toggleAttribute(qualifiedName: string, force?: boolean): boolean;
    webkitMatchesSelector(selectors: string): boolean;
    readonly baseURI: string;
    readonly childNodes: NodeListOf<ChildNode>;
    readonly firstChild: ChildNode;
    readonly isConnected: boolean;
    readonly lastChild: ChildNode;
    readonly nextSibling: ChildNode;
    readonly nodeName: string;
    readonly nodeType: number;
    nodeValue: string;
    readonly parentElement: HTMLElement;
    readonly parentNode: ParentNode;
    readonly previousSibling: ChildNode;
    textContent: string;
    appendChild<T extends Node>(node: T): T;
    cloneNode(deep?: boolean): Node;
    compareDocumentPosition(other: Node): number;
    contains(other: Node): boolean;
    getRootNode(options?: GetRootNodeOptions): Node;
    hasChildNodes(): boolean;
    insertBefore<T_1 extends Node>(node: T_1, child: Node): T_1;
    isDefaultNamespace(namespace: string): boolean;
    isEqualNode(otherNode: Node): boolean;
    isSameNode(otherNode: Node): boolean;
    lookupNamespaceURI(prefix: string): string;
    lookupPrefix(namespace: string): string;
    normalize(): void;
    removeChild<T_2 extends Node>(child: T_2): T_2;
    replaceChild<T_3 extends Node>(node: Node, child: T_3): T_3;
    readonly ATTRIBUTE_NODE: number;
    readonly CDATA_SECTION_NODE: number;
    readonly COMMENT_NODE: number;
    readonly DOCUMENT_FRAGMENT_NODE: number;
    readonly DOCUMENT_NODE: number;
    readonly DOCUMENT_POSITION_CONTAINED_BY: number;
    readonly DOCUMENT_POSITION_CONTAINS: number;
    readonly DOCUMENT_POSITION_DISCONNECTED: number;
    readonly DOCUMENT_POSITION_FOLLOWING: number;
    readonly DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: number;
    readonly DOCUMENT_POSITION_PRECEDING: number;
    readonly DOCUMENT_TYPE_NODE: number;
    readonly ELEMENT_NODE: number;
    readonly ENTITY_NODE: number;
    readonly ENTITY_REFERENCE_NODE: number;
    readonly NOTATION_NODE: number;
    readonly PROCESSING_INSTRUCTION_NODE: number;
    readonly TEXT_NODE: number;
    dispatchEvent(event: Event): boolean;
    ariaAtomic: string;
    ariaAutoComplete: string;
    ariaBusy: string;
    ariaChecked: string;
    ariaColCount: string;
    ariaColIndex: string;
    ariaColIndexText: string;
    ariaColSpan: string;
    ariaCurrent: string;
    ariaDisabled: string;
    ariaExpanded: string;
    ariaHasPopup: string;
    ariaHidden: string;
    ariaInvalid: string;
    ariaKeyShortcuts: string;
    ariaLabel: string;
    ariaLevel: string;
    ariaLive: string;
    ariaModal: string;
    ariaMultiLine: string;
    ariaMultiSelectable: string;
    ariaOrientation: string;
    ariaPlaceholder: string;
    ariaPosInSet: string;
    ariaPressed: string;
    ariaReadOnly: string;
    ariaRequired: string;
    ariaRoleDescription: string;
    ariaRowCount: string;
    ariaRowIndex: string;
    ariaRowIndexText: string;
    ariaRowSpan: string;
    ariaSelected: string;
    ariaSetSize: string;
    ariaSort: string;
    ariaValueMax: string;
    ariaValueMin: string;
    ariaValueNow: string;
    ariaValueText: string;
    role: string;
    animate(keyframes: PropertyIndexedKeyframes | Keyframe[], options?: number | KeyframeAnimationOptions): Animation;
    getAnimations(options?: GetAnimationsOptions): Animation[];
    after(...nodes: (string | Node)[]): void;
    before(...nodes: (string | Node)[]): void;
    remove(): void;
    replaceWith(...nodes: (string | Node)[]): void;
    innerHTML: string;
    readonly nextElementSibling: Element;
    readonly previousElementSibling: Element;
    readonly childElementCount: number;
    readonly children: HTMLCollection;
    readonly firstElementChild: Element;
    readonly lastElementChild: Element;
    append(...nodes: (string | Node)[]): void;
    prepend(...nodes: (string | Node)[]): void;
    querySelector<K_7 extends keyof HTMLElementTagNameMap>(selectors: K_7): HTMLElementTagNameMap[K_7];
    querySelector<K_8 extends keyof SVGElementTagNameMap>(selectors: K_8): SVGElementTagNameMap[K_8];
    querySelector<E_1 extends Element = Element>(selectors: string): E_1;
    querySelectorAll<K_9 extends keyof HTMLElementTagNameMap>(selectors: K_9): NodeListOf<HTMLElementTagNameMap[K_9]>;
    querySelectorAll<K_10 extends keyof SVGElementTagNameMap>(selectors: K_10): NodeListOf<SVGElementTagNameMap[K_10]>;
    querySelectorAll<E_2 extends Element = Element>(selectors: string): NodeListOf<E_2>;
    replaceChildren(...nodes: (string | Node)[]): void;
    readonly assignedSlot: HTMLSlotElement;
    oncopy: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    oncut: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    onpaste: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    readonly style: CSSStyleDeclaration;
    contentEditable: string;
    enterKeyHint: string;
    inputMode: string;
    readonly isContentEditable: boolean;
    onabort: (this: GlobalEventHandlers, ev: UIEvent) => any;
    onanimationcancel: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationend: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationiteration: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationstart: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onauxclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onbeforeinput: (this: GlobalEventHandlers, ev: InputEvent) => any;
    onblur: (this: GlobalEventHandlers, ev: FocusEvent) => any;
    oncancel: (this: GlobalEventHandlers, ev: Event) => any;
    oncanplay: (this: GlobalEventHandlers, ev: Event) => any;
    oncanplaythrough: (this: GlobalEventHandlers, ev: Event) => any;
    onchange: (this: GlobalEventHandlers, ev: Event) => any;
    onclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onclose: (this: GlobalEventHandlers, ev: Event) => any;
    oncontextmenu: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    oncuechange: (this: GlobalEventHandlers, ev: Event) => any;
    ondblclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    ondrag: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragend: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragenter: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragleave: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragover: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragstart: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondrop: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondurationchange: (this: GlobalEventHandlers, ev: Event) => any;
    onemptied: (this: GlobalEventHandlers, ev: Event) => any;
    onended: (this: GlobalEventHandlers, ev: Event) => any;
    onerror: OnErrorEventHandlerNonNull;
    onfocus: (this: GlobalEventHandlers, ev: FocusEvent) => any;
    onformdata: (this: GlobalEventHandlers, ev: FormDataEvent) => any;
    ongotpointercapture: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    oninput: (this: GlobalEventHandlers, ev: Event) => any;
    oninvalid: (this: GlobalEventHandlers, ev: Event) => any;
    onkeydown: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onkeypress: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onkeyup: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onload: (this: GlobalEventHandlers, ev: Event) => any;
    onloadeddata: (this: GlobalEventHandlers, ev: Event) => any;
    onloadedmetadata: (this: GlobalEventHandlers, ev: Event) => any;
    onloadstart: (this: GlobalEventHandlers, ev: Event) => any;
    onlostpointercapture: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onmousedown: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseenter: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseleave: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmousemove: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseout: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseover: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseup: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onpause: (this: GlobalEventHandlers, ev: Event) => any;
    onplay: (this: GlobalEventHandlers, ev: Event) => any;
    onplaying: (this: GlobalEventHandlers, ev: Event) => any;
    onpointercancel: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerdown: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerenter: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerleave: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointermove: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerout: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerover: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerup: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onprogress: (this: GlobalEventHandlers, ev: ProgressEvent<EventTarget>) => any;
    onratechange: (this: GlobalEventHandlers, ev: Event) => any;
    onreset: (this: GlobalEventHandlers, ev: Event) => any;
    onresize: (this: GlobalEventHandlers, ev: UIEvent) => any;
    onscroll: (this: GlobalEventHandlers, ev: Event) => any;
    onsecuritypolicyviolation: (this: GlobalEventHandlers, ev: SecurityPolicyViolationEvent) => any;
    onseeked: (this: GlobalEventHandlers, ev: Event) => any;
    onseeking: (this: GlobalEventHandlers, ev: Event) => any;
    onselect: (this: GlobalEventHandlers, ev: Event) => any;
    onselectionchange: (this: GlobalEventHandlers, ev: Event) => any;
    onselectstart: (this: GlobalEventHandlers, ev: Event) => any;
    onslotchange: (this: GlobalEventHandlers, ev: Event) => any;
    onstalled: (this: GlobalEventHandlers, ev: Event) => any;
    onsubmit: (this: GlobalEventHandlers, ev: SubmitEvent) => any;
    onsuspend: (this: GlobalEventHandlers, ev: Event) => any;
    ontimeupdate: (this: GlobalEventHandlers, ev: Event) => any;
    ontoggle: (this: GlobalEventHandlers, ev: Event) => any;
    ontouchcancel?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchend?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchmove?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchstart?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontransitioncancel: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionend: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionrun: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionstart: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    onvolumechange: (this: GlobalEventHandlers, ev: Event) => any;
    onwaiting: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationend: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationiteration: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationstart: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkittransitionend: (this: GlobalEventHandlers, ev: Event) => any;
    onwheel: (this: GlobalEventHandlers, ev: WheelEvent) => any;
    autofocus: boolean;
    readonly dataset: DOMStringMap;
    nonce?: string;
    tabIndex: number;
    blur(): void;
    focus(options?: FocusOptions): void;
    readonly $fastController: Controller;
    connectedCallback(): void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
};

/**
 * AuthConfig DI interface.
 *
 * @public
 */
export declare interface AuthConfig {
    /**
     * Connect automatically or require user to click a connect button.
     */
    autoConnect: boolean;
    /**
     * Login automatically or require user to click a login button after a connection is established.
     *
     * @remarks
     * Needs to manually be enabled in the NavigationContributor.
     */
    autoAuth: boolean;
    /**
     * Logo styles.
     *
     * @remarks
     * Providing `null` will hide the logo. Use content: url(...); to set source.
     *
     * @example Setting a custom logo
     * ```ts
     * logo: css`
     *     content: url(${customLogoImport});
     * `,
     * ```
     */
    logo: ElementStyles | null;
    /**
     * Background styles.
     *
     * @remarks
     * See {@link https://developer.mozilla.org/en-US/docs/Web/CSS/background} for more information.
     *
     * @example Setting a custom background image
     * ```ts
     * background: css`
     *     :host {
     *         background-image: url(${customBGImport});
     *     }
     * `,
     * ```
     */
    background: ElementStyles;
    /**
     * Omit any of the internal routes except 'login' and 'not-found'.
     *
     * @remarks
     * Routes specified here will not be configured nor will any internal cross-links to them be displayed.
     *
     * @example
     * ```ts
     * omitRoutes: ['request-account'],
     * ```
     */
    omitRoutes: Exclude<Routes, 'login' | 'not-found'>[];
    /**
     * Map of configuration for each of the primary form fields.
     *
     * @remarks
     * Use to drive inclusion / exclusion, tailor labels etc.
     */
    fields: FieldConfigMap;
    /**
     * Show or hide the connection status indicator.
     */
    showConnectionIndicator: boolean;
    /**
     * The `path` of the micro frontend as defined in the parent / host route.
     *
     * @remarks
     * Used to help resolve internal route links. Defaults to an empty string.
     */
    hostPath: string;
    /**
     * The default URL to route the user to after a successful login.
     *
     * @remarks
     * Session.returnUrl set via Session.captureReturnUrl() trumps this value.
     */
    defaultRedirectUrl: string;
    /**
     * Omit certain return URLs which the session service may have captured.
     *
     * @example
     * ```ts
     * omitRedirectUrls: ['/not-found'],
     * ```
     */
    omitRedirectUrls: string[];
    /**
     * The routing method called post login and logout.
     *
     * @remarks
     * By default, we use the FASTRouter which internally invokes the native History APIs. The post login url is the last
     * url visited by the user by default or undefined. The post logout url is a slash `/` by default. When overriding
     * this, you should include some protection and may want to ignore when the URL is equal to the current url.
     *
     * @param url - The url to route to or undefined.
     */
    routeToUrl: (url: string | undefined) => void;
    /**
     * SSO configuration.
     *
     * @remarks
     * Providing `null` excludes the SSO journey option completely.
     */
    sso: SSOConfig | null;
    /**
     * Display arbitrary version information.
     *
     * @remarks
     * Applications may choose to set this to display their Application release version on the login form.
     *
     * @example
     * ```ts
     * versionInformation: 'Version 3.0.0',
     * ```
     */
    versionInformation?: string;
}

/**
 * AuthConfig DI key.
 *
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export declare const AuthConfig: InterfaceSymbol<AuthConfig>;

/**
 * @public
 */
export declare type AuthDTO = LoginDTO | LogoutDTO;

/**
 * @public
 */
export declare type AuthEntity = LoginEntity | LogoutEntity;

/**
 * AuthError.
 * @public
 */
export declare class AuthError extends GenesisServerError {
    sent?: Message_2;
    received?: Message_2;
    constructor(sent?: Message_2, received?: Message_2, message?: string);
    hasPasswordExpiredError(): boolean;
}

/**
 * @public
 */
export declare type AuthEventMap = StoreRootEventDetailMap & AuthMachineEventMap & {
    'auth-login': AuthInfo;
    'auth-login-details': void;
    'auth-logout': void;
};

/**
 * @public
 */
export declare type AuthFormEntryEventMap = {
    'auth-autofill-form': void;
    'auth-organisation-changed': string;
    'auth-username-changed': string;
    'auth-email-changed': string;
    'auth-password-changed': string;
    'auth-password2-changed': string;
    'auth-showPasswords-changed': boolean;
};

/**
 * AuthFormEntryStore interface.
 * @public
 */
export declare interface AuthFormEntryStore extends Store {
    readonly host: string;
    readonly organisation: string;
    readonly username: string;
    readonly orgUsername: string;
    readonly email: string;
    readonly password: string;
    readonly password2: string;
    readonly showPasswords: boolean;
    readonly hasPasswordExpired: boolean;
    readonly passwordResetToken: string;
    readonly message: string;
    readonly hasErrors: boolean;
    readonly mfaCode: string;
    readonly idps: IDP[];
    readonly selectedIDP: string;
    readonly ssoToggled: boolean;
    readonly termsAgreed: boolean;
    onOrganisationChanged(event: CustomEvent<string>): void;
    onUsernameChanged(event: CustomEvent<string>): void;
    onEmailChanged(event: CustomEvent<string>): void;
    onPasswordChanged(event: CustomEvent<string>): void;
    onPassword2Changed(event: CustomEvent<string>): void;
    onShowPasswordsChanged(event: CustomEvent<boolean>): void;
    onAutofillForm(event: CustomEvent<void>): void;
}

/**
 * DI key of the store.
 * @internal
 */
export declare const AuthFormEntryStore: InterfaceSymbol<Key>;

/**
 * @beta
 * @privateRemarks
 * A hosted version of the MF that doesn't set up a design system or components. This is what apps would use to truly
 * customise the MF for their needs via define.ts.
 */
export declare class AuthHosted extends Auth {
    registerCommonComponents(): Promise<void>;
}

/**
 * AuthMachine interface.
 * @public
 */
export declare interface AuthMachine extends Machine<AuthMachineContext, AuthMachineEvent> {
}

/**
 * AuthMachine DI key.
 * @internal
 */
export declare const AuthMachine: InterfaceSymbol<AuthMachine>;

/**
 * AuthMachineContext interface.
 * @remarks
 * Transient state during the machine's execution.
 * @public
 */
export declare interface AuthMachineContext extends MachineContext {
    /**
     * The authentication credentials.
     * @remarks
     * Optional as it's possible to reauthenticate silently.
     */
    credentials?: AuthInfo;
    /**
     * The login/login DTO from the fetch machine.
     */
    authDTO: AuthDTO;
    /**
     * The login/login Entity mapped from the DTO.
     */
    authEntity: AuthEntity;
    /**
     * The mapper for the action being taken.
     */
    mapper: Mapper<AuthDTO, AuthEntity>;
    /**
     * The user, either authenticated or anonymous.
     */
    user: User;
}

/**
 * AuthMachineEvent type.
 * @remarks
 * The send action events used to invoke the machine.
 * @public
 */
export declare type AuthMachineEvent = {
    type: 'login';
    params: {
        credentials?: AuthInfo;
    };
} | {
    type: 'logout';
} | {
    type: 'openSocket';
} | {
    type: 'closeSocket';
} | {
    type: 'login-details';
} | DoneInvokeEvent<unknown> | ErrorEvent_2<unknown>;

/**
 * AuthMachineEventMap type.
 * @remarks
 * The mediation CustomEvent used to invoke machine actions.
 * @public
 */
export declare type AuthMachineEventMap = {
    'auth-machine-event': AuthMachineEvent;
};

/**
 * AuthStore interface.
 * @remarks
 * This is the root store for the foundation-auth package.
 * @public
 */
export declare interface AuthStore extends StoreRoot {
    readonly isPending: boolean;
    readonly formEntry: AuthFormEntryStore;
    /**
     * Auth workflows and transient state (context in xstate lingo).
     */
    readonly authMachine: AuthMachine;
    /**
     * @param event - The machine mediation event.
     */
    onMachineEvent(event: CustomEvent<AuthEventMap['auth-machine-event']>): void;
    onLogin(event: CustomEvent<AuthInfo>): void;
    onLoginDetails(event: CustomEvent<void>): void;
    onLogout(event: CustomEvent<void>): void;
}

/**
 * DI key of the store.
 * @internal
 */
export declare const AuthStore: InterfaceSymbol<Key>;

/**
 * @internal
 */
export declare const backButton: <T extends ConfigHost>(binding: Binding) => ViewTemplate<T, any>;

/**
 * @internal
 * @privateRemarks
 * Temp optimisation. How we handle images like this needs a broader review.
 */
export declare class BackgroundElement extends ConfigHostElement {
    connectedCallback(): void;
}

/**
 * @internal
 */
export declare class BaseRoute extends ConfigHostElement {
    store: AuthStore;
    user: User;
    auth: Auth_2;
    connect: Connect;
    session: Session;
    messageBuilder: MessageBuilder;
    credentialManager: CredentialManager;
    host: string;
    organisation: string;
    username: string;
    email: string;
    password: string;
    password2: string;
    showPasswords: boolean;
    message: string;
    hasErrors: boolean;
    isSubmitting: boolean;
    protected navigationPhase: NavigationPhase<Settings>;
    connectedCallback(): void;
    enter(phase: NavigationPhase<Settings>): void;
    onSubmit(): Promise<void>;
    ensureConnection(): Promise<boolean>;
    setError(message: string): void;
    clearError(): void;
    get orgUsername(): string;
    getSubRoutePath(routeName: Routes | string): string;
    onBack: () => void;
    onNavigate: (path: string) => void;
    queueOnBack(delay?: number): void;
    storeCredentials(password?: string): void;
    sendMessage<T = any>(message: Message_2<T>, successFeedback?: string, successCallback?: (result: any) => void): Promise<void>;
}

/**
 * @internal
 */
export declare type ConfigHost = {
    config: AuthConfig;
};

/**
 * @internal
 * @privateRemarks
 * For services / constructor injection, using `@optional(AuthConfig) config = defaultAuthConfig;` works as expected.
 * However, for elements, the `@optional` decorator isn't viable. This base element provides an alternative approach.
 */
export declare class ConfigHostElement extends ConfigHostElement_base implements ConfigHost {
    container: Container;
    config: AuthConfig;
    connectedCallback(): void;
}

declare const ConfigHostElement_base: abstract new (...args: any[]) => {
    $emit<K extends "auth-autofill-form" | "auth-organisation-changed" | "auth-username-changed" | "auth-email-changed" | "auth-password-changed" | "auth-password2-changed" | "auth-showPasswords-changed" | "store-connected" | "store-disconnected" | "store-ready" | "auth-machine-event" | "auth-login" | "auth-login-details" | "auth-logout">(...args: EventMap[K] extends void ? [type: K, options?: EmitOptions] : [type: K, detail: EventMap[K], options?: EmitOptions]): EmitReturn; /**
    * Fill with default values from config / env vars if needed.
    * For now using CredentialManager based auto-filling.
    * TODO: Review use cases.
    */
    accessKey: string;
    readonly accessKeyLabel: string;
    autocapitalize: string;
    dir: string;
    draggable: boolean;
    hidden: boolean;
    inert: boolean;
    innerText: string;
    lang: string;
    readonly offsetHeight: number;
    readonly offsetLeft: number;
    readonly offsetParent: Element;
    readonly offsetTop: number;
    readonly offsetWidth: number;
    outerText: string;
    spellcheck: boolean;
    title: string;
    translate: boolean;
    attachInternals(): ElementInternals;
    click(): void;
    addEventListener<K_1 extends keyof HTMLElementEventMap>(type: K_1, listener: (this: HTMLElement, ev: HTMLElementEventMap[K_1]) => any, options?: boolean | AddEventListenerOptions): void;
    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;
    removeEventListener<K_2 extends keyof HTMLElementEventMap>(type: K_2, listener: (this: HTMLElement, ev: HTMLElementEventMap[K_2]) => any, options?: boolean | EventListenerOptions): void;
    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;
    readonly attributes: NamedNodeMap;
    readonly classList: DOMTokenList;
    className: string;
    readonly clientHeight: number;
    readonly clientLeft: number;
    readonly clientTop: number;
    readonly clientWidth: number;
    id: string;
    readonly localName: string;
    readonly namespaceURI: string;
    onfullscreenchange: (this: Element, ev: Event) => any;
    onfullscreenerror: (this: Element, ev: Event) => any;
    outerHTML: string;
    readonly ownerDocument: Document;
    readonly part: DOMTokenList;
    readonly prefix: string;
    readonly scrollHeight: number;
    scrollLeft: number;
    scrollTop: number;
    readonly scrollWidth: number;
    readonly shadowRoot: ShadowRoot;
    slot: string;
    readonly tagName: string;
    attachShadow(init: ShadowRootInit): ShadowRoot;
    closest<K_3 extends keyof HTMLElementTagNameMap>(selector: K_3): HTMLElementTagNameMap[K_3];
    closest<K_4 extends keyof SVGElementTagNameMap>(selector: K_4): SVGElementTagNameMap[K_4];
    closest<E extends Element = Element>(selectors: string): E;
    getAttribute(qualifiedName: string): string;
    getAttributeNS(namespace: string, localName: string): string;
    getAttributeNames(): string[];
    getAttributeNode(qualifiedName: string): Attr;
    getAttributeNodeNS(namespace: string, localName: string): Attr;
    getBoundingClientRect(): DOMRect;
    getClientRects(): DOMRectList;
    getElementsByClassName(classNames: string): HTMLCollectionOf<Element>;
    getElementsByTagName<K_5 extends keyof HTMLElementTagNameMap>(qualifiedName: K_5): HTMLCollectionOf<HTMLElementTagNameMap[K_5]>;
    getElementsByTagName<K_6 extends keyof SVGElementTagNameMap>(qualifiedName: K_6): HTMLCollectionOf<SVGElementTagNameMap[K_6]>;
    getElementsByTagName(qualifiedName: string): HTMLCollectionOf<Element>;
    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/1999/xhtml", localName: string): HTMLCollectionOf<HTMLElement>;
    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/2000/svg", localName: string): HTMLCollectionOf<SVGElement>;
    getElementsByTagNameNS(namespace: string, localName: string): HTMLCollectionOf<Element>;
    hasAttribute(qualifiedName: string): boolean;
    hasAttributeNS(namespace: string, localName: string): boolean;
    hasAttributes(): boolean;
    hasPointerCapture(pointerId: number): boolean;
    insertAdjacentElement(where: InsertPosition, element: Element): Element;
    insertAdjacentHTML(position: InsertPosition, text: string): void;
    insertAdjacentText(where: InsertPosition, data: string): void;
    matches(selectors: string): boolean;
    releasePointerCapture(pointerId: number): void;
    removeAttribute(qualifiedName: string): void;
    removeAttributeNS(namespace: string, localName: string): void;
    removeAttributeNode(attr: Attr): Attr;
    requestFullscreen(options?: FullscreenOptions): Promise<void>;
    requestPointerLock(): void;
    scroll(options?: ScrollToOptions): void;
    scroll(x: number, y: number): void;
    scrollBy(options?: ScrollToOptions): void;
    scrollBy(x: number, y: number): void;
    scrollIntoView(arg?: boolean | ScrollIntoViewOptions): void;
    scrollTo(options?: ScrollToOptions): void;
    scrollTo(x: number, y: number): void;
    setAttribute(qualifiedName: string, value: string): void;
    setAttributeNS(namespace: string, qualifiedName: string, value: string): void;
    setAttributeNode(attr: Attr): Attr;
    setAttributeNodeNS(attr: Attr): Attr;
    setPointerCapture(pointerId: number): void;
    toggleAttribute(qualifiedName: string, force?: boolean): boolean;
    webkitMatchesSelector(selectors: string): boolean;
    readonly baseURI: string;
    readonly childNodes: NodeListOf<ChildNode>;
    readonly firstChild: ChildNode;
    readonly isConnected: boolean;
    readonly lastChild: ChildNode;
    readonly nextSibling: ChildNode;
    readonly nodeName: string;
    readonly nodeType: number;
    nodeValue: string;
    readonly parentElement: HTMLElement;
    readonly parentNode: ParentNode;
    readonly previousSibling: ChildNode;
    textContent: string;
    appendChild<T extends Node>(node: T): T;
    cloneNode(deep?: boolean): Node;
    compareDocumentPosition(other: Node): number;
    contains(other: Node): boolean;
    getRootNode(options?: GetRootNodeOptions): Node;
    hasChildNodes(): boolean;
    insertBefore<T_1 extends Node>(node: T_1, child: Node): T_1;
    isDefaultNamespace(namespace: string): boolean;
    isEqualNode(otherNode: Node): boolean;
    isSameNode(otherNode: Node): boolean;
    lookupNamespaceURI(prefix: string): string;
    lookupPrefix(namespace: string): string;
    normalize(): void;
    removeChild<T_2 extends Node>(child: T_2): T_2;
    replaceChild<T_3 extends Node>(node: Node, child: T_3): T_3;
    readonly ATTRIBUTE_NODE: number;
    readonly CDATA_SECTION_NODE: number;
    readonly COMMENT_NODE: number;
    readonly DOCUMENT_FRAGMENT_NODE: number;
    readonly DOCUMENT_NODE: number;
    readonly DOCUMENT_POSITION_CONTAINED_BY: number;
    readonly DOCUMENT_POSITION_CONTAINS: number;
    readonly DOCUMENT_POSITION_DISCONNECTED: number;
    readonly DOCUMENT_POSITION_FOLLOWING: number;
    readonly DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: number;
    readonly DOCUMENT_POSITION_PRECEDING: number;
    readonly DOCUMENT_TYPE_NODE: number;
    readonly ELEMENT_NODE: number;
    readonly ENTITY_NODE: number;
    readonly ENTITY_REFERENCE_NODE: number;
    readonly NOTATION_NODE: number;
    readonly PROCESSING_INSTRUCTION_NODE: number;
    readonly TEXT_NODE: number;
    dispatchEvent(event: Event): boolean;
    ariaAtomic: string;
    ariaAutoComplete: string;
    ariaBusy: string;
    ariaChecked: string;
    ariaColCount: string;
    ariaColIndex: string;
    ariaColIndexText: string;
    ariaColSpan: string;
    ariaCurrent: string;
    ariaDisabled: string;
    ariaExpanded: string;
    ariaHasPopup: string;
    ariaHidden: string;
    ariaInvalid: string;
    ariaKeyShortcuts: string;
    ariaLabel: string;
    ariaLevel: string;
    ariaLive: string;
    ariaModal: string;
    ariaMultiLine: string;
    ariaMultiSelectable: string;
    ariaOrientation: string;
    ariaPlaceholder: string;
    ariaPosInSet: string;
    ariaPressed: string;
    ariaReadOnly: string;
    ariaRequired: string;
    ariaRoleDescription: string;
    ariaRowCount: string;
    ariaRowIndex: string;
    ariaRowIndexText: string;
    ariaRowSpan: string;
    ariaSelected: string;
    ariaSetSize: string;
    ariaSort: string;
    ariaValueMax: string;
    ariaValueMin: string;
    ariaValueNow: string;
    ariaValueText: string;
    role: string;
    animate(keyframes: PropertyIndexedKeyframes | Keyframe[], options?: number | KeyframeAnimationOptions): Animation;
    getAnimations(options?: GetAnimationsOptions): Animation[];
    after(...nodes: (string | Node)[]): void;
    before(...nodes: (string | Node)[]): void;
    remove(): void;
    replaceWith(...nodes: (string | Node)[]): void;
    innerHTML: string;
    readonly nextElementSibling: Element;
    readonly previousElementSibling: Element;
    readonly childElementCount: number;
    readonly children: HTMLCollection;
    readonly firstElementChild: Element;
    readonly lastElementChild: Element;
    append(...nodes: (string | Node)[]): void;
    prepend(...nodes: (string | Node)[]): void;
    querySelector<K_7 extends keyof HTMLElementTagNameMap>(selectors: K_7): HTMLElementTagNameMap[K_7];
    querySelector<K_8 extends keyof SVGElementTagNameMap>(selectors: K_8): SVGElementTagNameMap[K_8];
    querySelector<E_1 extends Element = Element>(selectors: string): E_1;
    querySelectorAll<K_9 extends keyof HTMLElementTagNameMap>(selectors: K_9): NodeListOf<HTMLElementTagNameMap[K_9]>;
    querySelectorAll<K_10 extends keyof SVGElementTagNameMap>(selectors: K_10): NodeListOf<SVGElementTagNameMap[K_10]>;
    querySelectorAll<E_2 extends Element = Element>(selectors: string): NodeListOf<E_2>;
    replaceChildren(...nodes: (string | Node)[]): void;
    readonly assignedSlot: HTMLSlotElement;
    oncopy: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    oncut: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    onpaste: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    readonly style: CSSStyleDeclaration;
    contentEditable: string;
    enterKeyHint: string;
    inputMode: string;
    readonly isContentEditable: boolean;
    onabort: (this: GlobalEventHandlers, ev: UIEvent) => any;
    onanimationcancel: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationend: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationiteration: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationstart: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onauxclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onbeforeinput: (this: GlobalEventHandlers, ev: InputEvent) => any;
    onblur: (this: GlobalEventHandlers, ev: FocusEvent) => any;
    oncancel: (this: GlobalEventHandlers, ev: Event) => any;
    oncanplay: (this: GlobalEventHandlers, ev: Event) => any;
    oncanplaythrough: (this: GlobalEventHandlers, ev: Event) => any;
    onchange: (this: GlobalEventHandlers, ev: Event) => any;
    onclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onclose: (this: GlobalEventHandlers, ev: Event) => any;
    oncontextmenu: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    oncuechange: (this: GlobalEventHandlers, ev: Event) => any;
    ondblclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    ondrag: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragend: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragenter: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragleave: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragover: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragstart: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondrop: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondurationchange: (this: GlobalEventHandlers, ev: Event) => any;
    onemptied: (this: GlobalEventHandlers, ev: Event) => any;
    onended: (this: GlobalEventHandlers, ev: Event) => any;
    onerror: OnErrorEventHandlerNonNull;
    onfocus: (this: GlobalEventHandlers, ev: FocusEvent) => any;
    onformdata: (this: GlobalEventHandlers, ev: FormDataEvent) => any;
    ongotpointercapture: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    oninput: (this: GlobalEventHandlers, ev: Event) => any;
    oninvalid: (this: GlobalEventHandlers, ev: Event) => any;
    onkeydown: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onkeypress: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onkeyup: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onload: (this: GlobalEventHandlers, ev: Event) => any;
    onloadeddata: (this: GlobalEventHandlers, ev: Event) => any;
    onloadedmetadata: (this: GlobalEventHandlers, ev: Event) => any;
    onloadstart: (this: GlobalEventHandlers, ev: Event) => any;
    onlostpointercapture: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onmousedown: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseenter: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseleave: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmousemove: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseout: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseover: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseup: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onpause: (this: GlobalEventHandlers, ev: Event) => any;
    onplay: (this: GlobalEventHandlers, ev: Event) => any;
    onplaying: (this: GlobalEventHandlers, ev: Event) => any;
    onpointercancel: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerdown: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerenter: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerleave: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointermove: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerout: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerover: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerup: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onprogress: (this: GlobalEventHandlers, ev: ProgressEvent<EventTarget>) => any;
    onratechange: (this: GlobalEventHandlers, ev: Event) => any;
    onreset: (this: GlobalEventHandlers, ev: Event) => any;
    onresize: (this: GlobalEventHandlers, ev: UIEvent) => any;
    onscroll: (this: GlobalEventHandlers, ev: Event) => any;
    onsecuritypolicyviolation: (this: GlobalEventHandlers, ev: SecurityPolicyViolationEvent) => any;
    onseeked: (this: GlobalEventHandlers, ev: Event) => any;
    onseeking: (this: GlobalEventHandlers, ev: Event) => any;
    onselect: (this: GlobalEventHandlers, ev: Event) => any;
    onselectionchange: (this: GlobalEventHandlers, ev: Event) => any;
    onselectstart: (this: GlobalEventHandlers, ev: Event) => any;
    onslotchange: (this: GlobalEventHandlers, ev: Event) => any;
    onstalled: (this: GlobalEventHandlers, ev: Event) => any;
    onsubmit: (this: GlobalEventHandlers, ev: SubmitEvent) => any;
    onsuspend: (this: GlobalEventHandlers, ev: Event) => any;
    ontimeupdate: (this: GlobalEventHandlers, ev: Event) => any;
    ontoggle: (this: GlobalEventHandlers, ev: Event) => any;
    ontouchcancel?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchend?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchmove?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchstart?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontransitioncancel: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionend: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionrun: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionstart: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    onvolumechange: (this: GlobalEventHandlers, ev: Event) => any;
    onwaiting: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationend: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationiteration: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationstart: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkittransitionend: (this: GlobalEventHandlers, ev: Event) => any;
    onwheel: (this: GlobalEventHandlers, ev: WheelEvent) => any;
    autofocus: boolean;
    readonly dataset: DOMStringMap;
    nonce?: string;
    tabIndex: number;
    blur(): void;
    focus(options?: FocusOptions): void;
    readonly $fastController: Controller;
    connectedCallback(): void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
};

/**
 * Configure the auth micro frontend settings.
 *
 * @remarks
 * This is primarily for general settings, rather than re-defining the element, static templating / style changes.
 *
 * @param container - DI container.
 * @param config - A partial AuthConfig.
 *
 * @example Configuring auth on lazy load
 * ```ts
 * name: 'login',
 * path: 'login',
 * title: 'Login',
 * element: async () => {
 *   const { configure, define, defaultAuthConfig } = await import('@genesislcap/foundation-auth');
 *   configure(this.container, {
 *     autoConnect: true,
 *     omitRoutes: ['request-account'],
 *     fields: {
 *       ...defaultAuthConfig.fields,
 *       organisation: {
 *         label: 'CompID',
 *       },
 *     },
 *     hostPath: 'login',
 *     defaultRedirectUrl: 'dashboard',
 *     logo: authLogo,
 *     background: authBG,
 *   });
 *   // You can import and return `Auth` directly here or re-define it completely via `define`.
 *   return define({
 *     name: `nexus-login`,
 *   });
 * },
 * layout: authLayout,
 * settings: { public: true },
 * childRouters: true,
 * ```
 *
 * @public
 * @privateRemarks
 * We can tailor the spreading logic after we put it to use. Keeping it simple for now.
 */
export declare function configure(container: Container, config: Partial<AuthConfig>): void;

/**
 * @public
 */
export declare const defaultApiHost: string;

/**
 * Default AuthConfig DI implementation.
 * @public
 */
export declare const defaultAuthConfig: AuthConfig;

/**
 * Default implementation of the store.
 * @public
 */
export declare class DefaultAuthFormEntryStore extends AbstractStore<AuthFormEntryStore, AuthFormEntryEventMap, InternalEventMap> implements AuthFormEntryStore {
    protected config: AuthConfig;
    protected credentialManager: CredentialManager;
    host: string;
    organisation: string;
    username: string;
    email: string;
    password: string;
    password2: string;
    showPasswords: boolean;
    hasPasswordExpired: boolean;
    passwordResetToken: string;
    message: string;
    hasErrors: boolean;
    mfaCode: string;
    idps: IDP[];
    selectedIDP: string;
    ssoToggled: boolean;
    termsAgreed: boolean;
    get orgUsername(): string;
    constructor();
    private autofill;
    onOrganisationChanged: EventListener;
    onUsernameChanged: EventListener;
    onEmailChanged: EventListener;
    onPasswordChanged: EventListener;
    onPassword2Changed: EventListener;
    onShowPasswordsChanged: EventListener;
    onAutofillForm: EventListener;
}

/**
 * Default AuthMachine.
 * @public
 */
export declare class DefaultAuthMachine extends AbstractMachine<AuthMachineContext, AuthMachineEvent> implements AuthMachine {
    private user;
    private connect;
    private fetchMachine;
    private messageBuilder;
    private credentialManager;
    private uuid;
    private loginMapper;
    private logoutMapper;
    private config;
    constructor(user: User, connect: Connect, fetchMachine: FetchMachine, messageBuilder: MessageBuilder, credentialManager: CredentialManager, uuid: UUID, loginMapper: LoginMapper, logoutMapper: LogoutMapper, config: AuthConfig);
    start(options?: InterpreterOptions<typeof DefaultAuthMachine.machine>): void;
    /**
     * AuthMachine is a singleton.
     */
    getFromContainer(): this;
    createFetchMachineEvent(url: string, msg?: Message_2): FetchMachineEvent;
    addLoginEvents(): {
        login: {
            actions: string[];
            target: string;
        };
        "login-details": {
            target: string;
        };
    };
}

/**
 * Default AuthMachineContext.
 * @public
 */
export declare const defaultAuthMachineContext: Partial<AuthMachineContext>;

/**
 * Default implementation of the store.
 * @public
 */
export declare class DefaultAuthStore extends AbstractStoreRoot<AuthStore, AuthEventMap, InternalAuthEventMap> implements AuthStore {
    readonly config: AuthConfig;
    readonly authMachine: AuthMachine;
    readonly formEntry: AuthFormEntryStore;
    constructor(config: AuthConfig, authMachine: AuthMachine, formEntry: AuthFormEntryStore);
    get isPending(): boolean;
    onMachineEvent: EventListener;
    onLogin: EventListener;
    onLoginDetails: EventListener;
    onLogout: EventListener;
}

/**
 * Default LoginMapper.
 * @public
 */
export declare class DefaultLoginMapper implements LoginMapper {
    /**
     * {@inheritDoc Mapper.toEntity}
     */
    toEntity: (dto: LoginDTO) => Promise<LoginEntity>;
    protected fromSystemDTO: (system: System_2) => System;
    protected fromProductDTO: (products: Product_2[]) => Product[];
}

/**
 * Default LogoutMapper.
 * @public
 */
export declare class DefaultLogoutMapper implements LogoutMapper {
    /**
     * {@inheritDoc Mapper.toEntity}
     */
    toEntity: (dto: LogoutDTO) => Promise<LogoutEntity>;
}

/**
 * @internal
 */
export declare const defaultOnBackMS = 3000;

/**
 * @public
 */
export declare const defaultOrganisation: string;

/**
 * @public
 */
export declare const defaultPassword: string;

/**
 * @public
 */
export declare const defaultSocketExt: string;

/**
 * The default template options this MF has been created with.
 * @beta
 * @privateRemarks
 * This will likely evolve into the shell style PWA + FDC3 manifest setup, but that needs more work to evolve into MVP.
 * Hosts should be able to figure out everything they will need to do to fully customise a MF. Currently, they
 * import these `defaultTemplateOptions` and the host dev overrides. Each TemplateComponents key must be a mandatory
 * override, given in hosted mode the MFs won't be registering fallbacks as this would be wasteful, bloat etc.
 * I've added the components list to the package.json \> config block for now, but I'm not using it here.
 */
export declare const defaultTemplateOptions: TemplateOptions;

/**
 * Default User implementation.
 * @public
 */
export declare class DefaultUser implements User {
    pathHistory: string[];
    actionHistory: unknown[];
    sessionAuthToken: string;
    refreshAuthToken: string;
    sessionId: string;
    userKVs: {
        [key: string]: any;
    };
    details: Details;
    permission: string[];
    profile: string[];
    sourceRef: string;
    userName: string;
    set(entity: Partial<LoginAck>): this;
    unset(): this;
    protected userNameChanged(): void;
    get username(): string;
    isAuthenticated(): boolean;
    isAnonymous(): boolean;
    isAdmin(): boolean;
    isBanned(): boolean;
    hasPermission(permission: string | string[]): boolean;
    hasProfile(profile: string | string[]): boolean;
    trackPath(ignoreEmpty?: boolean): string;
    clearPaths(): void;
    lastPath(): string;
    trackAction<TDetails = unknown>(details: TDetails): void;
    clearActions(): void;
    lastAction(): unknown;
    protected hasKey(keys: string[], key: string | string[]): boolean;
}

/**
 * @public
 */
export declare const defaultUser: string;

/**
 * Re-define the auth micro frontend.
 *
 * @example
 * ```ts
 * import { define, styles, template, defaultTemplateOptions } from '@genesislcap/foundation-auth';
 * const customTemplateOptions = {
 *   ...defaultTemplateOptions,
 *   ...customOptions,
 * }
 * export const AppAuth = define({
 *   name: `nexus-auth`,
 *   template: template(customTemplateOptions),
 *   styles: css`
 *     ${styles(customTemplateOptions)}
 *     some-element {
 *       background-color: #ff00b4;
 *     }
 *  `,
 * });
 * ```
 *
 * @beta
 * @privateRemarks
 * TODO: Use AuthHosted instead of Auth when elements manifest stuff lands, which will drive tagFor etc.
 */
export declare const define: DefineFunction<typeof Auth>;

/**
 * @beta
 * @remarks
 * This is the main definition of this micro frontend which is exposed for user reconfiguration.
 */
export declare const definition: PartialFASTElementDefinition;

/**
 * @public
 */
export declare interface Details {
    readonly system: System | null;
    readonly heartbeatIntervalSecs: number;
    readonly failedLoginAttempts: number;
    readonly rejectedLoginAttempts: number;
    readonly lastLoginDatetime: number;
    readonly daysToPasswordExpiry: number;
    readonly product: Product[];
}

/**
 * @public
 */
declare interface Details_2 {
    readonly SYSTEM: System_2;
    readonly HEARTBEAT_INTERVAL_SECS: number;
    readonly FAILED_LOGIN_ATTEMPTS: number;
    readonly REJECTED_LOGIN_ATTEMPTS: number;
    readonly LAST_LOGIN_DATETIME: number;
    readonly DAYS_TO_PASSWORD_EXPIRY: number;
    readonly PRODUCT: Product_2[];
}

/**
 * @internal
 */
export declare const emailField: <T extends BaseRoute>() => ViewTemplate<T, any>;

/**
 * @public
 */
export declare interface EVENT_LOGIN_AUTH_ACK extends ACK {
    readonly SESSION_AUTH_TOKEN: string;
    readonly REFRESH_AUTH_TOKEN: string;
    readonly SESSION_ID: string;
    readonly USER_NAME: string;
    readonly UPDATE_QUEUE: string;
    readonly ZERO_MQ_PROXY_MODE_ENABLED: boolean;
    readonly ZERO_MQ_PROXY_INBOUND_PORT: number;
    readonly ZERO_MQ_PROXY_OUTBOUND_PORT: number;
    /**
     * @privateRemarks
     * This is not the actual "user", it is random JSON / key value pairs set by BE app devs.
     *
     * @example
     * ```json
     * "USER" : {
     *   "USER_TYPE" : "USER",
     *   "USER_ACCESS_TYPE" : "ALL",
     *   "ADDRESS_LINE1" : "JohnDoe Street",
     *   "TEST_CONFIGURATION" : "TEST"
     * }
     * ```
     */
    readonly USER: {
        [key: string]: any;
    };
    readonly DETAILS: Details_2;
    readonly PERMISSION: string[];
    readonly PROFILE: string[];
}

/**
 * @public
 */
export declare interface EVENT_LOGIN_AUTH_NACK extends NACK {
}

/**
 * @public
 */
export declare interface EVENT_LOGIN_DETAILS_ACK extends EVENT_LOGIN_AUTH_ACK {
}

/**
 * @public
 */
export declare interface EVENT_LOGOUT_NACK extends NACK {
}

declare type EventMap = AuthEventMap & AuthFormEntryEventMap & {};

/**
 * Request SSO identity provider list
 *
 * @public
 */
export declare const fetchIDPs: (path?: string, host?: string) => Promise<IDP[]>;

/**
 * @public
 * Could be expanded to allow field ViewTemplates.
 */
export declare type FieldConfig = {
    label: string;
    /**
     * @privateRemarks
     * Added for now to apply defaults, but I'm not convinced we should do this. Could be made reactive after upgrade.
     */
    value?: any;
    /**
     * @remarks
     * We expect fields to be required by default, but you can override to make them optional. Organisation for example.
     */
    required?: boolean;
    /**
     * @remarks
     * A regular expression the control's value should match. Please note the email field has its own built in pattern.
     */
    pattern?: string;
    /**
     * @remarks
     * Used in conjunction with the pattern to explain the conditions.
     */
    title?: string;
};

/**
 * @public
 * @privateRemarks
 * Using null to exclude the organisation field rather than boolean, as it affords cleaner value lookups in the templates.
 */
export declare type FieldConfigMap = {
    organisation: FieldConfig | null;
    username: FieldConfig;
    email: FieldConfig;
    password: FieldConfig;
};

/**
 * fromDTOAck
 * @param dto - ACK.
 * @public
 */
export declare const fromDTOAck: (dto: ACK) => Ack;

/**
 * fromDTONack
 * @param dto - NACK.
 * @public
 */
export declare const fromDTONack: (dto: NACK) => Nack;

/**
 * @public
 */
export declare const fromDTONackErrorWarningArray: (arr: NACK_ERROR_WARNING[]) => NackErrorWarning[];

/**
 * @public
 */
export declare const fromDTOStringArray: (arr: string[]) => string[];

/**
 * Get SSO identity provider login URL
 *
 * @public
 */
export declare const getSSOLoginURL: (idp: any, path?: string, host?: string) => string;

/**
 * hasDTOErrorWarningCode
 * @remarks
 * Checks both the `CODE` and `STATUS_CODE` values for a match.
 * @param dto - NACK.
 * @param code - The error or warning code.
 * @public
 */
export declare const hasDTOErrorWarningCode: (dto: NACK, code: string) => boolean;

/**
 * @public
 */
export declare const hostEnv: string;

/**
 * @public
 */
export declare const hostUrl: string;

/**
 * @public
 */
export declare interface IDP {
    id: string;
    type: string;
}

/**
 * @public
 */
export declare interface IDPResponse {
    ID: string;
    TYPE: string;
}

/**
 * includesErrorWarningCode
 * @public
 */
export declare const includesErrorWarningCode: (arr: NACK_ERROR_WARNING[], code: string) => boolean;

/**
 * @internal
 */
export declare const inputEmit: <K extends KeysMatching<EventMap, string>>(type: K, options?: EmitOptions) => Binding<any, any, any>;

declare type InternalAuthEventMap = {};

declare type InternalEventMap = {};

/**
 * @public
 */
export declare const isAuthError: (error: unknown) => boolean;

/**
 * isLoginAckDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLoginAckDTO(dto: LoginDTO): dto is EVENT_LOGIN_AUTH_ACK;

/**
 * isLoginAckEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLoginAckEntity(entity: LoginEntity): entity is LoginAck;

/**
 * isLoginDetailsAckDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLoginDetailsAckDTO(dto: LoginDTO): dto is EVENT_LOGIN_DETAILS_ACK;

/**
 * isLoginDetailsAckEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLoginDetailsAckEntity(entity: LoginEntity): entity is LoginDetailsAck;

/**
 * isLoginNackDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLoginNackDTO(dto: LoginDTO): dto is EVENT_LOGIN_AUTH_NACK;

/**
 * isLoginNackEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLoginNackEntity(entity: LoginEntity): entity is LoginNack;

/**
 * isLogoutAckDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLogoutAckDTO(dto: LogoutDTO): dto is LOGOUT_ACK;

/**
 * isLogoutAckEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLogoutAckEntity(entity: LogoutEntity): entity is LogoutAck;

/**
 * isLogoutNackDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLogoutNackDTO(dto: LogoutDTO): dto is EVENT_LOGOUT_NACK;

/**
 * isLogoutNackEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLogoutNackEntity(entity: LogoutEntity): entity is LogoutNack;

/**
 * A utility to check if a pathname is a route of this micro frontend.
 *
 * @param pathname - A pathname string to check, typically location.pathname, which is used when a value is omitted.
 *
 * @public
 * @privateRemarks
 * I've just put this util in for now given there's some app level direction code in place which needs review.
 */
export declare function isMFRoute(pathname?: string): boolean;

/**
 * @public
 */
export declare const logger: Logger;

/**
 * @public
 */
export declare let LOGIN_DETAILS_URL: string;

/**
 * @public
 */
export declare let LOGIN_REFRESH_URL: string;

/**
 * @public
 */
export declare let LOGIN_URL: string;

/**
 * @public
 */
export declare interface LoginAck extends Ack {
    readonly sessionAuthToken: string;
    readonly refreshAuthToken: string;
    readonly sessionId: string;
    readonly userName: string;
    readonly updateQueue: string;
    readonly zeroMqProxyModeEnabled: boolean;
    readonly zeroMqProxyInboundPort: number;
    readonly zeroMqProxyOutboundPort: number;
    readonly userKVs: {
        [key: string]: any;
    };
    readonly details: Details;
    readonly permission: string[];
    readonly profile: string[];
}

/**
 * @public
 */
export declare interface LoginDetailsAck extends LoginAck {
}

/**
 * LoginDTO type.
 * @public
 */
export declare type LoginDTO = EVENT_LOGIN_AUTH_ACK | EVENT_LOGIN_DETAILS_ACK | EVENT_LOGIN_AUTH_NACK;

/**
 * LoginEntity type.
 * @public
 */
export declare type LoginEntity = LoginAck | LoginDetailsAck | LoginNack;

/**
 * LoginMapper interface.
 *
 * @remarks
 * An extensible mapper for converting between login DTOs and Entities, where you can normalise data, implement derived
 * fields, validation etc.
 *
 * @example Overriding the default mapper for your application. Note the interface is the key.
 * ```ts
 * import { DefaultLoginMapper, LoginMapper } from '@genesislcap/foundation-auth';
 * import { Container, Registration } from '@microsoft/fast-foundation';
 *
 * class MyLoginMapper extends DefaultLoginMapper {
 *     // modify logic
 * }
 *
 * @customElement({...})
 * export class MyApplication extends FASTElement {
 *     @Container container!: Container;
 *     connectedCallback() {
 *         this.container.register(Registration.singleton(LoginMapper, MyLoginMapper));
 *     }
 * }
 * ```
 *
 * @public
 */
export declare interface LoginMapper extends Mapper<LoginDTO, LoginEntity> {
}

/**
 * LoginMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const LoginMapper: InterfaceSymbol<LoginMapper>;

/**
 * @public
 */
export declare interface LoginNack extends Nack {
    readonly isMFARequired: boolean;
    readonly hasPasswordExpired: boolean;
}

/**
 * @internal
 */
export declare class LogoElement extends ConfigHostElement {
}

/**
 * @public
 */
export declare interface LOGOUT_ACK extends ACK {
    readonly OIDC_LOGOUT_URL: string;
}

/**
 * @public
 */
export declare let LOGOUT_URL: string;

/**
 * @public
 */
export declare interface LogoutAck extends Ack {
    readonly oidcLogoutUrl: string;
}

/**
 * LogoutDTO type.
 * @public
 */
export declare type LogoutDTO = LOGOUT_ACK | EVENT_LOGOUT_NACK;

/**
 * LogoutEntity type.
 * @public
 */
export declare type LogoutEntity = LogoutAck | LogoutNack;

/**
 * LogoutMapper interface.
 *
 * @remarks
 * An extensible mapper for converting between logout DTOs and Entities, where you can normalise data, implement derived
 * fields, validation etc.
 *
 * @public
 */
export declare interface LogoutMapper extends Mapper<LogoutDTO, LogoutEntity> {
}

/**
 * LogoutMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const LogoutMapper: InterfaceSymbol<LogoutMapper>;

/**
 * @public
 */
export declare interface LogoutNack extends Nack {
}

/**
 * Base implementation of a routing used with the Auth class
 *
 * @internal
 */
export declare class MainRouterConfig extends RouterConfiguration<Settings> {
    private user;
    private container;
    private analytics;
    private authConfig;
    constructor(user: User, container: Container, analytics: FoundationAnalytics, authConfig: AuthConfig);
    configure(): void;
    construct<T>(Type: Constructable<T>): T;
}

/**
 * DTO mapper interface.
 * @typeParam TDTO - The dto type.
 * @typeParam TEntity - The entity type.
 * @public
 */
export declare interface Mapper<TDTO, TEntity> {
    /**
     * Converts a DTO to an entity.
     * @param dto - The DTO to convert.
     * @returns Promise of the resulting entity.
     */
    toEntity: (dto: TDTO) => Promise<TEntity>;
    /**
     * Converts an entity to a DTO.
     * @remarks
     * This is optionally implemented as many DTOs are never sent back to the server.
     * @param entity - The entity to convert.
     * @returns Promise of the resulting DTO.
     */
    toDTO?: (entity: Partial<TEntity>) => Promise<TDTO>;
}

/**
 * @internal
 */
declare interface MESSAGE {
    readonly MESSAGE_TYPE: string;
    readonly SOURCE_REF: string;
}

/**
 * @internal
 */
declare interface Message {
    readonly messageType: string;
    readonly sourceRef: string;
}

/**
 * @internal
 * @privateRemarks
 * Temp optimisation. How we handle images like this needs a broader review.
 */
export declare class MessageElement extends FASTElement {
    classNames: string;
    message: string;
    nonError: boolean;
    nonErrorChanged(): void;
}

/**
 * @internal
 */
declare interface NACK extends MESSAGE {
    readonly ERROR: NACK_ERROR_WARNING[];
    readonly WARNING: NACK_ERROR_WARNING[];
}

/**
 * @internal
 */
declare interface Nack extends Message {
    readonly error: NackErrorWarning[];
    readonly warning: NackErrorWarning[];
}

/**
 * @internal
 */
declare interface NACK_ERROR_WARNING {
    readonly '@type': string;
    readonly CODE: string;
    readonly STATUS_CODE: string;
    readonly TEXT: string;
}

/**
 * @internal
 */
declare interface NackErrorWarning {
    readonly type: string;
    readonly code: string;
    readonly statusCode: string;
    readonly text: string;
}

/**
 * @internal
 */
export declare const organisationField: <T extends BaseRoute>() => ViewTemplate<T, any>;

/**
 * @internal
 */
export declare const password2Field: <T extends BaseRoute>(type: 'new' | 'confirmation') => ViewTemplate<T, any>;

/**
 * @internal
 */
export declare const passwordField: <T extends BaseRoute>(label?: string) => ViewTemplate<T, any>;

/**
 * @public
 */
export declare interface Product {
    readonly name: string;
    readonly version: string;
}

/**
 * @public
 */
declare interface Product_2 {
    readonly NAME: string;
    readonly VERSION: string;
}

/**
 * @public
 */
export declare const Routes: {
    readonly login: "login";
    readonly 'request-account': "request-account";
    readonly 'reset-password': "reset-password";
    readonly 'forgot-password': "forgot-password";
    readonly verify: "verify";
    readonly protected: "protected";
    readonly 'not-found': "not-found";
};

/**
 * @public
 */
export declare type Routes = (typeof Routes)[keyof typeof Routes];

/**
 * @internal
 */
export declare const selectEmit: <K extends KeysMatching<EventMap, string>>(type: K, options?: EmitOptions) => Binding<any, any, any>;

/**
 * Defines the parameters you may set on the routes.
 *
 * @remarks
 * See the example in the {@link Auth} class in the router's `configure` method for usage. All parameters are Optional.
 *
 * @public
 */
export declare type Settings = {
    /**
     * Controls whether the user has to be logged in to view.
     */
    public?: boolean;
};

/**
 * @internal
 */
export declare const showPasswordsCheckbox: <T extends BaseRoute>() => ViewTemplate<T, any>;

/**
 * @public
 */
export declare let SOCKET_URL: string;

/**
 * @public
 */
export declare type SSOConfig = {
    /**
     * Optionally toggle the SSO journey on/off by default.
     */
    toggled?: boolean;
    /**
     * The identity providers path under the current host.
     *
     * @example
     * ```ts
     * identityProvidersPath: 'sso/list'
     * ```
     */
    identityProvidersPath: string;
};

/**
 * @internal
 * @privateRemarks
 * This is used during development of this micro frontend.
 */
export declare const standaloneDefinition: PartialFASTElementDefinition;

/**
 * @public
 * @privateRemarks
 * Options can be used to target unknown component tags in the css, such as:
 * @example unknown target
 * ```
 * const buttonTag = tagFor(options.button);
 * ...
 * ${buttonTag} {
 *   width: 200px;
 * }
 * ```
 */
export declare const styles: (options: TemplateOptions) => ElementStyles;

/**
 * @internal
 */
export declare const submitButton: <T extends ConfigHost>(label: string, dataTestId?: string, disabled?: boolean) => ViewTemplate<T, any>;

/**
 * @internal
 */
export declare class SubmittingIndicator extends FASTElement {
    isSubmitting: boolean;
}

/**
 * @public
 */
export declare interface System {
    readonly date: string;
}

/**
 * @public
 */
declare interface System_2 {
    readonly DATE: string;
}

/**
 * @public
 */
export declare const template: (options: TemplateOptions) => ViewTemplate<Auth, any>;

/**
 * @beta
 * @privateRemarks
 * The CLI can be used to monitor what is in use and needs a mapping.
 */
export declare type TemplateComponents = {
    anchor: TemplateElementDependency;
    button: TemplateElementDependency;
    card: TemplateElementDependency;
    checkbox: TemplateElementDependency;
    listboxOption: TemplateElementDependency;
    provider: TemplateElementDependency;
    router: TemplateElementDependency;
    select: TemplateElementDependency;
    textField: TemplateElementDependency;
};

/**
 * @beta
 */
export declare type TemplateOptions = TemplateComponents & {
    somePartial?: string | SyntheticViewTemplate;
};

/**
 * User interface.
 * @privateRemarks
 * Providing `username` and `userName` for backwards compatability.
 * @public
 */
export declare interface User extends UserPathHistory, UserActionHistory {
    readonly sessionAuthToken: string;
    readonly refreshAuthToken: string;
    readonly sessionId: string;
    readonly userKVs: {
        [key: string]: any;
    };
    readonly details: Details;
    readonly profile: string[];
    readonly sourceRef: string;
    readonly userName: string;
    readonly username: string;
    set(entity: Partial<LoginAck>): this;
    unset(): this;
    isAuthenticated(): boolean;
    isAnonymous(): boolean;
    isAdmin(): boolean;
    isBanned(): boolean;
    hasPermission(permission: string | string[]): boolean;
    hasProfile(profile: string | string[]): boolean;
}

/**
 * User DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const User: InterfaceSymbol<User>;

/**
 * UserActionHistory.
 * @remarks
 * APIs to track a user's action history.
 * @privateRemarks
 * Integrate with foundation analytics? Users could then simply call `user.trackAction` and we could engage analytics.
 * @public
 */
export declare interface UserActionHistory {
    /**
     * Array of actions that have been tracked.
     */
    readonly actionHistory: unknown[];
    /**
     * Track an action.
     */
    trackAction<TDetails = unknown>(details: TDetails): void;
    /**
     * Clears action history.
     */
    clearActions(): void;
    /**
     * @returns The last stored action.
     */
    lastAction(): unknown;
}

/**
 * @internal
 */
export declare const usernameField: <T extends BaseRoute>() => ViewTemplate<T, any>;

/**
 * UserPathHistory.
 * @remarks
 * APIs to track a user's path history. Includes the pathname, search and hash only.
 * This is not intended proxy or replace the History API.
 * @privateRemarks
 * Integrate with foundation analytics? Users could then simply call `user.trackPath` and we could engage analytics.
 * @public
 */
export declare interface UserPathHistory {
    /**
     * Array of paths that have been tracked.
     */
    readonly pathHistory: string[];
    /**
     * Track current path.
     *
     * @param ignoreEmpty - Ignore empty paths. Defaults to false.
     */
    trackPath(ignoreEmpty?: boolean): string;
    /**
     * Clears path history.
     */
    clearPaths(): void;
    /**
     * May be used to return to a target path after authentication.
     * @returns The last stored path.
     */
    lastPath(): string | undefined;
}

export { }
